@@ -28,11 +28,9 @@ import tempfile
 import time
 import xml.dom.minidom
 
-
 from otopi import plugin
 from otopi import util
 
-
 from ovirt_hosted_engine_setup import constants as ohostedcons
 from ovirt_hosted_engine_setup import domains as ohosteddomains
 
@@ -52,8 +50,10 @@ class Plugin(plugin.PluginBase):
     def __init__(self, context):
         super(Plugin, self).__init__(context=context)
         self._checker = ohosteddomains.DomainChecker()
+        # TODO: remove once the engine is able to handle this
+        self.query_for_additional_mnt_options = False
 
-    def _mount(self, path, connection, domain_type):
+    def _mount(self, path, connection, domain_type, mnt_options):
         fstype = ''
         opts = []
 
@@ -74,6 +74,11 @@ class Plugin(plugin.PluginBase):
             '-t%s' % fstype,
         )
 
+        if mnt_options:
+            opts.extend(
+                mnt_options.split(',')
+            )
+
         if opts:
             mount_cmd += (
                 '-o%s' % ','.join(opts),
@@ -295,14 +300,20 @@ class Plugin(plugin.PluginBase):
                 ohostedcons.StorageEnv.STORAGE_DOMAIN_CONNECTION
             ] = path
 
-    def _validateDomain(self, connection, domain_type, check_space):
+    def _validateDomain(
+        self,
+        connection,
+        domain_type,
+        check_space,
+        mnt_options,
+    ):
         if self.environment[
             ohostedcons.StorageEnv.DOMAIN_TYPE
         ] == ohostedcons.DomainTypes.GLUSTERFS:
             self._check_volume_properties(connection)
         path = tempfile.mkdtemp()
         try:
-            self._mount(path, connection, domain_type)
+            self._mount(path, connection, domain_type, mnt_options)
             self._checker.check_valid_path(path)
             self._check_domain_rights(path)
             self._checker.check_base_writable(path)
@@ -375,6 +386,23 @@ class Plugin(plugin.PluginBase):
                     prompt=True,
                     caseSensitive=True,
                 )
+                if self.query_for_additional_mnt_options:
+                    mnt_options = self.environment[
+                        ohostedcons.StorageEnv.MNT_OPTIONS
+                    ]
+                    self.environment[
+                        ohostedcons.StorageEnv.MNT_OPTIONS
+                    ] = self.dialog.queryString(
+                        name='OVEHOSTED_STORAGE_DOMAIN_MNT_OPTIONS',
+                        note=_(
+                            'If needed, specify additional mount options for '
+                            'the connection to the hosted-engine storage'
+                            'domain [@DEFAULT@]: '
+                        ),
+                        prompt=True,
+                        caseSensitive=True,
+                        default=mnt_options if mnt_options else '',
+                    )
             try:
                 self._fix_path_syntax()
                 self._validateDomain(
@@ -385,6 +413,9 @@ class Plugin(plugin.PluginBase):
                         ohostedcons.StorageEnv.DOMAIN_TYPE
                     ],
                     check_space=False,
+                    mnt_options=self.environment[
+                        ohostedcons.StorageEnv.MNT_OPTIONS
+                    ],
                 )
                 validDomain = True
             except (ValueError, RuntimeError) as e:
@@ -440,9 +471,6 @@ class Plugin(plugin.PluginBase):
             ohostedcons.Stages.DIALOG_TITLES_E_STORAGE,
         ),
         condition=lambda self: (
-            not self.environment[
-                ohostedcons.CoreEnv.IS_ADDITIONAL_HOST
-            ] and
             self.environment[ohostedcons.StorageEnv.DOMAIN_TYPE] in (
                 ohostedcons.DomainTypes.GLUSTERFS,
                 ohostedcons.DomainTypes.NFS3,
@@ -465,6 +493,9 @@ class Plugin(plugin.PluginBase):
                     ohostedcons.StorageEnv.DOMAIN_TYPE
                 ],
                 check_space=True,
+                mnt_options=self.environment[
+                    ohostedcons.StorageEnv.MNT_OPTIONS
+                ],
             )
         except ohosteddomains.InsufficientSpaceError as e:
             self.logger.debug('exception', exc_info=True)
